smartcard.CardConnectionEvent.CardConnectionEvent

# ``smartcard`.`CardConnectionEvent`.`CardConnectionEvent``

class documentation

`class CardConnectionEvent(object):`

View In Hierarchy

Base class for card connection events.

This event is notified by CardConnection objects.

Method | `__init__` | No summary
Instance Variable | `args` | Undocumented
Instance Variable | `type` | Undocumented

def __init__(self, type, args=None):

Parameters
type | 'connect', 'reconnect', 'disconnect', 'command', 'response'
args | None for 'connect', 'reconnect' or 'disconnect' command APDU byte list for 'command' [response data, sw1, sw2] for 'response'

args =

Undocumented

type =

Undocumented